@@ -36,12 +36,9 @@
 #include <stdio.h>
 #include <fcntl.h>
 
-using std::string;
-using std::exception;
+unsigned int StringtoIP(const std::string& ip);
 
-unsigned int StringtoIP(const string& ip);
-
-string IPtoString(unsigned int ip);
+std::string IPtoString(unsigned int ip);
 
 class Buffer;
 
@@ -55,8 +52,6 @@ class TCPSocket {
   
  private:
   static const unsigned int max_receive_size = 4096;
-  
-  unsigned long gethostname(const char *hostname);
 
   int m_socketDescriptor;
   bool m_socketDescriptor_valid;
@@ -66,6 +61,9 @@ class TCPSocket {
 
   void fcntlSetup();
 
+ public:
+  static unsigned long gethostname(const char *hostname);
+
  public:
   TCPSocket();
   ~TCPSocket();
@@ -88,6 +86,7 @@ class TCPSocket {
   void setRemoteHost(const char *host);
   void setRemotePort(unsigned short port);
   void setRemoteIP(unsigned int ip);
+  void setBindHost(const char *host);
   
   void setBlocking(bool b);
   bool isBlocking() const;
@@ -118,6 +117,8 @@ class TCPServer {
   void StartServer(unsigned short lower, unsigned short upper);
   void Disconnect();
 
+  void setBindHost(const char *host);
+
   bool isStarted() const;
 
   // blocking accept
@@ -128,12 +129,12 @@ class TCPServer {
 
 };
 
-class SocketException : exception {
+class SocketException : std::exception {
  private:
-  string m_errortext;
+  std::string m_errortext;
 
  public:
-  SocketException(const string& text);
+  SocketException(const std::string& text);
   ~SocketException() throw() { }
 
   const char* what() const throw();
