@@ -28,8 +28,9 @@
 
 #include <stdlib.h>
 
+using std::string;
 using std::ostringstream;
-using SigC::slot;
+using std::endl;
 
 namespace ICQ2000 {
 
@@ -88,7 +89,7 @@ namespace ICQ2000 {
   void DirectClient::Init() {
     m_seqnum = 0xFFFF;
     m_msgcache.setDefaultTimeout(30);
-    m_msgcache.expired.connect( slot(this, &DirectClient::expired_cb) );
+    m_msgcache.expired.connect( this, &DirectClient::expired_cb );
   }
 
   void DirectClient::Connect() {
@@ -177,7 +178,7 @@ namespace ICQ2000 {
 	  } else {
 	    m_state = CONNECTED;
 	    flush_queue();
-	    connected.emit();
+	    connected.emit(this);
 	  }
 	}
 
@@ -192,7 +193,7 @@ namespace ICQ2000 {
 	    ConfirmUIN();
 	    m_state = CONNECTED;          // v5 is done handshaking now
 	    flush_queue();
-	    connected.emit();
+	    connected.emit(this);
 	  }
 
 	} else {
@@ -211,7 +212,7 @@ namespace ICQ2000 {
 
 	m_state = CONNECTED;
 	flush_queue();
-	connected.emit();
+	connected.emit(this);
 
       } else if (m_state == CONNECTED) {
 	ParsePacket(sb);
@@ -224,7 +225,7 @@ namespace ICQ2000 {
 	 * as it probably means they are faulty
 	 */
 	ostringstream ostr;
-	ostr  << "Buffer pointer not at end after parsing packet was: 0x" << hex << sb.pos()
+	ostr  << "Buffer pointer not at end after parsing packet was: 0x" << std::hex << sb.pos()
 	      << " should be: 0x" << sb.size();
 	SignalLog(LogEvent::WARN, ostr.str());
       }
@@ -379,8 +380,7 @@ namespace ICQ2000 {
 
     unsigned int unknown;
     b >> unknown // 0x0000000a
-      >> unknown;// 0x00000001 on genuine connections, otherwise some weird connections which we drop
-    if (unknown != 0x00000001) throw DisconnectedException("Ignoring weird direct connection");
+      >> unknown;
     b.advance(24); // unknowns
   }
 
@@ -433,9 +433,11 @@ namespace ICQ2000 {
 
     b >> checksum
       >> command
-      >> unknown // 0x000e
+      >> unknown // 0x000e or 0x0012 in probe packets
       >> seqnum;
 
+    if (unknown != 0x000e) throw ParseException("Ignoring weird packet");
+    
     b.advance(12); // unknown 3 ints
 
     ICQSubType *i = ICQSubType::ParseICQSubType(b, true, (command == V6_TCP_ACK));
