@@ -325,6 +325,18 @@ string XmlBranch::toString(int n) {
   return ret;
 }
 
+list<string> XmlBranch::getChildren() const {
+  list<string> r;
+
+  list<XmlNode*>::const_iterator curr = children.begin();
+  while (curr != children.end()) {
+    r.push_back((*curr)->getTag());
+    curr++;
+  }
+
+  return r;
+}
+
 // ----------- XmlLeaf --------------------------
 
 XmlLeaf::XmlLeaf(const string& t, const string& v)
