@@ -110,6 +110,18 @@ void accountmanager::exec() {
 			break;
 		}
 
+		switch(pname) {
+		    case jabber:
+			if(account.additional["prio"].empty()) {
+			    account.additional["prio"] = "4";
+			    conf.setourid(account);
+			}
+
+			t.addleaff(n, 0, citem+14, " Priority : %s ",
+			    account.additional["prio"].c_str());
+			break;
+		}
+
 		t.addleaff(n, 0, citem+5, capab.count(hookcapab::optionalpassword) ?
 		    _(" Password (optional) : %s ") : _(" Password : %s "),
 		    string(account.password.size(), '*').c_str());
@@ -230,6 +242,16 @@ void accountmanager::exec() {
 			    account.port = icqconf::defservers[account.pname].port;
 		    }
 		    break;
+
+		case 14:
+		    tmp = leadcut(trailcut(face.inputstr(spname + _(" priority: "),
+			account.additional["prio"])));
+
+		    if(face.getlastinputkey() != KEY_ESC)
+		    if(i2str(atoi(tmp.c_str())) == tmp)
+			account.additional["prio"] = tmp;
+
+		    break;
 	    }
 
 	    if(action != 7) {
