@@ -1,7 +1,7 @@
 /*
 *
 * centericq core routines
-* $Id: centericq.cc,v 1.169 2003/10/01 18:48:11 konst Exp $
+* $Id: centericq.cc,v 1.176 2003/11/21 16:51:49 konst Exp $
 *
 * Copyright (C) 2001-2003 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -28,6 +28,7 @@
 #include "irchook.h"
 #include "yahoohook.h"
 #include "rsshook.h"
+#include "ljhook.h"
 #include "icqface.h"
 #include "icqcontact.h"
 #include "icqcontacts.h"
@@ -38,7 +39,7 @@
 
 centericq::centericq()
     : timer_checkmail(0), timer_update(0), timer_resend(0),
-      timer_autosave(/*time(0)*/0), regmode(false)
+      timer_autosave(0), regmode(false)
 {
 }
 
@@ -227,6 +228,11 @@ void centericq::mainloop() {
 		    c->getpostponed()), icqface::ok);
 		break;
 
+	    case ACT_LJ:
+		sendevent(imxmlevent(c->getdesc(),
+		    imevent::outgoing, c->getpostponed()), icqface::ok);
+		break;
+
 	    case ACT_CONTACT:
 		sendevent(imcontacts(c->getdesc(), imevent::outgoing, vector< pair<unsigned int, string> >()),
 		    icqface::ok);
@@ -497,7 +503,7 @@ void centericq::linkfeed() {
 	    c->setworkinfo(wi);
 
 	    icqcontact::moreinfo mi = c->getmoreinfo();
-	    mi.birth_day = s.checkfrequency;
+	    mi.checkfreq = s.checkfrequency;
 	    c->setmoreinfo(mi);
 
 	    c->setnick(s.nick);
@@ -515,10 +521,6 @@ void centericq::find() {
     while(ret) {
 	if(ret = face.finddialog(s, icqface::fsuser)) {
 	    switch(s.pname) {
-		case icq:
-		    ret = face.findresults(s);
-		    break;
-
 		case infocard:
 		    c = clist.addnew(imcontact(0, infocard), true);
 		    c->setnick(s.nick);
@@ -602,20 +604,22 @@ bool centericq::updateconf() {
 }
 
 void centericq::checkmail() {
-    const char *fname = getenv("MAIL");
+    if(!getenv("MAIL"))
+	return;
+
     struct stat st;
     int mcount = 0;
     char buf[512];
-    string lastfrom;
+    string lastfrom, fname(getenv("MAIL"));
     bool prevempty, header;
     FILE *f;
 
     static int fsize = -1;
     static int oldcount = -1;
 
-    if(conf.getmailcheck() && fname)
-    if(!stat(fname, &st))
-    if(st.st_size != fsize) {
+    if(conf.getmailcheck())
+    if(!stat(fname.c_str(), &st)) 
+    if(st.st_size != fsize && (st.st_mode & S_IFREG)) {
 
 	if(fsize != -1 && st.st_size > fsize) {
 	    /*
@@ -624,7 +628,7 @@ void centericq::checkmail() {
 	    *
 	    */
 
-	    if(f = fopen(fname, "r")) {
+	    if(f = fopen(fname.c_str(), "r")) {
 		prevempty = header = true;
 
 		while(!feof(f)) {
@@ -660,6 +664,55 @@ void centericq::checkmail() {
 	}
 
 	fsize = st.st_size;
+
+    } else if(st.st_mode & S_IFDIR) {
+	DIR *d;
+	struct dirent *e;
+	string dname;
+	time_t last = -1;
+
+	dname = (string) fname + "/new/";
+
+	if(!stat(dname.c_str(), &st) && st.st_mode & S_IFDIR)
+	if(d = opendir(dname.c_str())) {
+	    fname = "";
+
+	    while((e = readdir(d)))
+	    if(!stat((dname+e->d_name).c_str(), &st) && (st.st_mode & S_IFREG)) {
+		mcount++;
+		if(st.st_mtime >= last) {
+		    last = st.st_mtime;
+		    fname = dname + e->d_name;
+		}
+	    }
+
+	    closedir(d);
+
+	    if(f = fopen(fname.c_str(), "r")) {
+		header = true;
+		while(header && !feof(f)) {
+		    freads(f, buf, 512);
+		    if(!strncmp(buf, "From: ", 6)) {
+			lastfrom = strim(buf+6);
+			header = false; // we're done
+		    }
+		}
+		fclose(f);
+	    }
+
+	    if(mcount && (oldcount == -1 || (mcount > oldcount)))  {
+		const struct tm *lt;
+		lt = localtime(&timer_current);
+
+		face.log(_("+ [%02d:%02d:%02d] new mail arrived, %d messages"),
+		    lt->tm_hour, lt->tm_min, lt->tm_sec, mcount);
+
+		face.log(_("+ last msg from %s"), lastfrom.c_str());
+		clist.get(contactroot)->playsound(imevent::email);
+	    }
+
+	    oldcount = mcount;
+	}
     }
 }
 
@@ -813,24 +866,53 @@ bool centericq::sendevent(const imevent &ev, icqface::eventviewresult r) {
 
     if(ev.gettype() == imevent::message) {
 	const immessage *m = dynamic_cast<const immessage *>(&ev);
-
 	text = m->gettext();
 
 	if(r == icqface::reply) {
-	    if(conf.getquote()) {
-		text = quotemsg(text);
-	    } else {
-		text = "";
+	    if(m->getcontact().pname == rss)
+	    if(islivejournal(m->getcontact())) {
+		imxmlevent *x = new imxmlevent(m->getcontact(), imevent::outgoing, "");
+
+		string url = clist.get(m->getcontact())->getmoreinfo().homepage;
+		int npos = text.rfind(url), id = 0;
+		if(npos != -1) id = strtoul(text.c_str()+url.size()+npos, 0, 0);
+
+		x->setfield("_eventkind", "comment");
+		x->setfield("replyto", i2str(id));
+		sendev = x;
 	    }
+
+	    if(conf.getquote()) text = quotemsg(text);
+		else text = "";
+
 	} else if(r == icqface::forward) {
 	    text = fwdnote + text;
 	}
 
-	sendev = new immessage(m->getcontact(), imevent::outgoing, text);
+	if(!sendev) {
+	    sendev = new immessage(m->getcontact(), imevent::outgoing, text);
+	}
+
+    } else if(ev.gettype() == imevent::xml) {
+	const imxmlevent *m = dynamic_cast<const imxmlevent *>(&ev);
+	text = m->gettext();
+
+	if(r == icqface::reply) {
+	    if(conf.getquote()) text = quotemsg(text);
+		else text = "";
+
+	} else if(r == icqface::forward) {
+	    text = fwdnote + text;
+	    sendev = new immessage(m->getcontact(), imevent::outgoing, text);
+
+	}
+
+	if(!sendev) {
+	    sendev = new imxmlevent(m->getcontact(), imevent::outgoing, text);
+	}
 
     } else if(ev.gettype() == imevent::url) {
 	const imurl *m = dynamic_cast<const imurl *>(&ev);
-
 	text = m->getdescription();
 
 	switch(r) {
@@ -935,6 +1017,9 @@ bool centericq::sendevent(const imevent &ev, icqface::eventviewresult r) {
 	}
 
 	if(proceed) {
+	    if(r == icqface::forward)
+		sendev->setcontact(imcontact());
+
 	    if(proceed = face.eventedit(*sendev))
 	    if(proceed = !sendev->empty()) {
 		for(i = face.muins.begin(); i != face.muins.end(); ++i) {
@@ -1003,7 +1088,7 @@ icqface::eventviewresult centericq::readevent(const imevent &ev, bool &enough, b
 
 	case icqface::open:
 	    if(const imurl *m = static_cast<const imurl *>(&ev))
-		conf.openurl(m->geturl());
+		conf.execaction("openurl", m->geturl());
 	    break;
 
 	case icqface::accept:
@@ -1198,9 +1283,27 @@ icqcontact *centericq::addcontact(const imcontact &ic) {
     }
 
     if(!c) {
-	c = clist.addnew(ic, false);
+	if(ic.pname == rss) {
+	    c = clist.addnew(imcontact(0, rss), false);
+	    icqcontact::workinfo wi = c->getworkinfo();
+	    wi.homepage = ic.nickname;
+	    c->setworkinfo(wi);
+
+	    if(!ic.nickname.empty()) {
+		string bfeed = ic.nickname;
+		getrword(bfeed, "/");
+		c->setnick(getrword(bfeed, "/") + "@lj");
+		c->setdispnick(c->getnick());
+		gethook(ic.pname).sendnewuser(c);
+	    }
+
+	} else {
+	    c = clist.addnew(ic, false);
+	}
+
     } else {
 	c->includeintolist();
+
     }
 
     c->setgroupid(groupid);
@@ -1504,6 +1607,20 @@ bool ischannel(const imcontact &cont) {
     return false;
 }
 
+bool islivejournal(const icqcontact *c) {
+    bool r = false;
+#ifdef BUILD_LJ
+    if(c->getnick().size() > 3)
+	r = c->getnick().substr(c->getnick().size()-3) == "@lj";
+#endif
+    return r;
+}
+
+bool islivejournal(const imcontact &cont) {
+    icqcontact *c = clist.get(cont);
+    return c ? islivejournal(c) : false;
+}
+
 string up(string s) {
     string::iterator is = s.begin();
     while(is != s.end()) {
