@@ -1,7 +1,7 @@
 /*
 *
 * centericq IM protocol abstraction class
-* $Id: abstracthook.cc,v 1.44 2003/09/30 11:38:42 konst Exp $
+* $Id: abstracthook.cc,v 1.48 2003/11/21 00:35:33 konst Exp $
 *
 * Copyright (C) 2001,2002,2003 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -26,7 +26,6 @@
 
 #include "icqhook.h"
 #include "yahoohook.h"
-#include "msnhook.h"
 #include "aimhook.h"
 #include "irchook.h"
 #include "jabberhook.h"
@@ -172,6 +171,9 @@ vector<pair<string, string> > abstracthook::getregparameters(const string &agent
 void abstracthook::updatecontact(icqcontact *c) {
 }
 
+void abstracthook::renamegroup(const string &oldname, const string &newname) {
+}
+
 string abstracthook::rushtmlconv(const string &tdir, const string &text, bool rus) {
     int pos;
     string r = rus ? rusconv(tdir, text) : text;
@@ -200,7 +202,9 @@ string abstracthook::rushtmlconv(const string &tdir, const string &text, bool ru
 	    if(r.substr(pos+1, 5) == "#150;") r.replace(pos, 6, "-"); else
 	    if(r.substr(pos+1, 5) == "#151;") r.replace(pos, 6, "--"); else
 	    if(r.substr(pos+1, 5) == "#146;") r.replace(pos, 6, "`"); else
+	    if(r.substr(pos+1, 4) == "#39;") r.replace(pos, 5, "'"); else
 	    if(r.substr(pos+1, 6) == "#8211;") r.replace(pos, 7, "--"); else
+	    if(r.substr(pos+1, 6) == "#8230;") r.replace(pos, 7, "..."); else
 	    if(r.substr(pos+1, 7) == "hellip;") r.replace(pos, 8, "..."); else
 	    if(r.substr(pos+1, 6) == "laquo;") r.replace(pos, 7, "<<"); else
 	    if(r.substr(pos+1, 6) == "raquo;") r.replace(pos, 7, ">>"); else
@@ -300,6 +304,29 @@ string abstracthook::getmd5(const string &text) {
     return r;
 }
 
+void abstracthook::requestfromfound(const imcontact &ic) {
+    vector<icqcontact *>::const_iterator ig = foundguys.begin();
+
+    while(ig != foundguys.end()) {
+	if((*ig)->getdesc() == ic) {
+	    icqcontact *rc = clist.get(ic);
+	    if(!rc) rc = clist.get(contactroot);
+
+	    rc->setnick((*ig)->getnick());
+	    rc->setbasicinfo((*ig)->getbasicinfo());
+	    rc->setmoreinfo((*ig)->getmoreinfo());
+	    rc->setworkinfo((*ig)->getworkinfo());
+	    rc->setinterests((*ig)->getinterests());
+	    rc->setbackground((*ig)->getbackground());
+	    rc->setabout((*ig)->getabout());
+
+	    break;
+	}
+
+	++ig;
+    }
+}
+
 // ----------------------------------------------------------------------------
 
 abstracthook &gethook(protocolname pname) {
@@ -310,9 +337,6 @@ abstracthook &gethook(protocolname pname) {
 #ifdef BUILD_YAHOO
 	case yahoo: return yhook;
 #endif
-#ifdef BUILD_MSN
-	case msn: return mhook;
-#endif
 #ifdef BUILD_AIM
 	case aim: return ahook;
 #endif
