@@ -32,7 +32,7 @@ struct hookcapab {
 	ssl,
 	channelpasswords,
 	groupchatservices,
-	nochat
+	nochat,
     };
 };
 
@@ -44,6 +44,14 @@ struct servicetype {
     };
 };
 
+struct groupoperation {
+    enum enumeration {
+	add,
+	remove,
+	rename
+    };
+};
+
 class abstracthook {
     protected:
 	enum Encoding {
@@ -54,6 +62,7 @@ class abstracthook {
 	imstatus manualstatus;
 	verticalmenu *searchdest;
 	set<hookcapab::enumeration> fcapabs;
+	vector<icqcontact *> foundguys;
 
 	string rusconv(const string &tdir, const string &text);
 	string rushtmlconv(const string &tdir, const string &text, bool rus = true);
@@ -61,6 +70,8 @@ class abstracthook {
 
 	string getmd5(const string &text);
 
+	void requestfromfound(const imcontact &ic);
+
     public:
 	abstracthook(protocolname aproto);
 
@@ -120,6 +131,7 @@ class abstracthook {
 	virtual vector<pair<string, string> > getregparameters(const string &agentname) const;
 
 	virtual void updatecontact(icqcontact *c);
+	virtual void renamegroup(const string &oldname, const string &newname);
 };
 
 abstracthook &gethook(protocolname pname);
