@@ -1,7 +1,7 @@
 /*
 *
 * centericq IRC protocol handling class
-* $Id: irchook.cc,v 1.70 2003/07/07 18:51:01 konst Exp $
+* $Id: irchook.cc,v 1.74 2003/11/05 09:07:42 konst Exp $
 *
 * Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -77,7 +77,7 @@ void irchook::init() {
 	if(ischannel(c))
 	if(c->getbasicinfo().requiresauth) {
 	    channels.push_back(channelInfo(c->getdesc().nickname));
-	    channels.back().joined = 1;
+	    channels.back().joined = true;
 	    channels.back().passwd = c->getbasicinfo().zip;
 	}
     }
@@ -89,7 +89,7 @@ void irchook::init() {
     firetalk_register_callback(handle, FC_IM_GOTINFO, &gotinfo);
     firetalk_register_callback(handle, FC_IM_GOTCHANNELS, &gotchannels);
     firetalk_register_callback(handle, FC_IM_GETMESSAGE, &getmessage);
-    firetalk_register_callback(handle, FC_IM_GETACTION, &getmessage);
+    firetalk_register_callback(handle, FC_IM_GETACTION, &getaction);
     firetalk_register_callback(handle, FC_IM_BUDDYONLINE, &buddyonline);
     firetalk_register_callback(handle, FC_IM_BUDDYOFFLINE, &buddyoffline);
     firetalk_register_callback(handle, FC_IM_BUDDYAWAY, &buddyaway);
@@ -99,6 +99,7 @@ void irchook::init() {
     firetalk_register_callback(handle, FC_CHAT_END_EXTENDED, &endextended);
     firetalk_register_callback(handle, FC_CHAT_NAMES, &chatnames);
     firetalk_register_callback(handle, FC_CHAT_GETMESSAGE, &chatmessage);
+    firetalk_register_callback(handle, FC_CHAT_GETACTION, &chataction);
     firetalk_register_callback(handle, FC_CHAT_JOINED, &chatjoined);
     firetalk_register_callback(handle, FC_CHAT_LEFT, &chatleft);
     firetalk_register_callback(handle, FC_CHAT_KICKED, &chatkicked);
@@ -114,6 +115,7 @@ void irchook::init() {
     firetalk_register_callback(handle, FC_FILE_ERROR, &fileerror);
     firetalk_register_callback(handle, FC_CHAT_USER_JOINED, &chatuserjoined);
     firetalk_register_callback(handle, FC_CHAT_USER_LEFT, &chatuserleft);
+    firetalk_register_callback(handle, FC_CHAT_USER_KICKED, &chatuserkicked);
     firetalk_register_callback(handle, FC_CHAT_GOTTOPIC, &chatgottopic);
     firetalk_register_callback(handle, FC_CHAT_USER_OPPED, &chatuseropped);
     firetalk_register_callback(handle, FC_CHAT_USER_DEOPPED, &chatuserdeopped);
@@ -221,7 +223,7 @@ bool irchook::isconnecting() const {
 
 bool irchook::send(const imevent &ev) {
     icqcontact *c = clist.get(ev.getcontact());
-    string text;
+    string text, cmd;
 
     if(c) {
 	if(ev.gettype() == imevent::message) {
@@ -253,8 +255,30 @@ bool irchook::send(const imevent &ev) {
 	}
 
 	if(text.substr(0, 1) == "/") {
-	    rawcommand(text.substr(1));
-	    return true;
+	    text.erase(0, 1);
+	    cmd = up(getword(text));
+
+	    if(cmd == "ME") {
+		if(ischannel(c)) return firetalk_chat_send_action(handle,
+		    c->getdesc().nickname.c_str(), text.c_str(), 0) == FE_SUCCESS;
+		else return firetalk_im_send_action(handle,
+		    c->getdesc().nickname.c_str(), text.c_str(), 0) == FE_SUCCESS;
+
+	    } else if(cmd == "KICK") {
+		text = cmd + " " + c->getdesc().nickname + " " + text;
+
+	    } else if(cmd == "OP") {
+		text = (string) "mode " + c->getdesc().nickname + " +o " + text;
+
+	    } else if(cmd == "DEOP") {
+		text = (string) "mode " + c->getdesc().nickname + " -o " + text;
+
+	    } else {
+		text.insert(0, cmd + " ");
+
+	    }
+
+	    rawcommand(text);
 	}
 
 	if(ischannel(c)) {
@@ -378,6 +402,7 @@ void irchook::lookup(const imsearchparams &params, verticalmenu &dest) {
 	smode = Channel;
 
 	while(!(room = getword(rooms)).empty()) {
+	    if(room[0] != '#') room.insert(0, "#");
 	    searchchannels.push_back(room);
 	    ic = find(channels.begin(), channels.end(), room);
 
@@ -869,6 +894,25 @@ void irchook::getmessage(void *conn, void *cli, ...) {
     DLOG("getmessage");
 }
 
+void irchook::getaction(void *conn, void *cli, ...) {
+    va_list ap;
+  
+    va_start(ap, cli);
+    char *sender = va_arg(ap, char *);
+    int automessage_flag = va_arg(ap, int);
+    char *message = va_arg(ap, char *);
+    va_end(ap);
+    
+    if(sender && message)
+    if(strlen(sender) && strlen(message)) {
+	em.store(immessage(imcontact(sender, irc), imevent::incoming, 
+	    ((string) "* " + sender + " " + 
+		irhook.rushtmlconv("wk", cuthtml(message, true))).c_str()));
+    }
+    
+    DLOG("getaction");
+}
+
 void irchook::buddyonline(void *conn, void *cli, ...) {
     va_list ap;
 
@@ -1090,6 +1134,27 @@ void irchook::chatmessage(void *connection, void *cli, ...) {
     }
 }
 
+void irchook::chataction(void *connection, void *cli, ...) {
+    va_list ap;
+    string imsg;
+
+    va_start(ap, cli);
+    char *room = va_arg(ap, char *);
+    char *from = va_arg(ap, char *);
+    int automessage = va_arg(ap, int);
+    char *msg = va_arg(ap, char *);
+    va_end(ap);
+
+    if(from && msg)
+    if(strlen(from) && strlen(msg))
+    if(clist.get(imcontact(room, irc))) {
+	em.store(immessage(imcontact(room, irc), imevent::incoming,
+	    ((string) "* " + from + " " +
+		irhook.rushtmlconv("wk", cuthtml(msg, true))).c_str()));
+    }
+}
+
+
 void irchook::chatjoined(void *connection, void *cli, ...) {
     va_list ap;
 
@@ -1098,7 +1163,7 @@ void irchook::chatjoined(void *connection, void *cli, ...) {
     va_end(ap);
 
     icqcontact *c = clist.get(imcontact(room, irc));
-    if(c) c->setstatus(available);
+    if(c) c->setstatus(available, false);
 }
 
 void irchook::chatleft(void *connection, void *cli, ...) {
@@ -1109,7 +1174,7 @@ void irchook::chatleft(void *connection, void *cli, ...) {
     va_end(ap);
 
     icqcontact *c = clist.get(imcontact(room, irc));
-    if(c) c->setstatus(offline);
+    if(c) c->setstatus(offline, false);
 }
 
 void irchook::chatkicked(void *connection, void *cli, ...) {
@@ -1372,6 +1437,32 @@ void irchook::chatuserleft(void *conn, void *cli, ...) {
     }
 }
 
+void irchook::chatuserkicked(void *conn, void *cli, ...) {
+    va_list ap;
+
+    va_start(ap, cli);
+    char *room = va_arg(ap, char *);
+    char *who = va_arg(ap, char *);
+    char *by = va_arg(ap, char *);
+    char *reason = va_arg(ap, char *);
+    va_end(ap);
+
+    if(conf.getourid(irc).nickname != who) {
+	string text;
+	char buf[512];
+
+	sprintf(buf, _("%s has been kicked by %s"), who, by); text = buf;
+
+	if(reason)
+	if(strlen(reason)) {
+	    sprintf(buf, _("reason: %s"), reason);
+	    text += (string) "; " + buf + ".";
+	}
+
+	em.store(imnotification(imcontact(room, irc), text));
+    }
+}
+
 void irchook::chatgottopic(void *conn, void *cli, ...) {
     va_list ap;
 
@@ -1381,6 +1472,11 @@ void irchook::chatgottopic(void *conn, void *cli, ...) {
     char *author = va_arg(ap, char *);
     va_end(ap);
 
+    vector<channelInfo>::const_iterator ic = find(irhook.channels.begin(), irhook.channels.end(), room);
+
+    if(ic == irhook.channels.end() || !ic->joined)
+	return;
+
     string text;
     char buf[1024];
     sprintf(buf, _("Channel topic now is: %s"), topic);
@@ -1436,7 +1532,9 @@ void irchook::chatopped(void *conn, void *cli, ...) {
     va_end(ap);
 
     char buf[512];
-    sprintf(buf, _("%s has opped us."), by);
+    if(by) sprintf(buf, _("%s has opped us."), by);
+	else strcpy(buf, _("you are an op here"));
+
     em.store(imnotification(imcontact(room, irc), buf));
 }
 
