@@ -1,7 +1,7 @@
 /*
 *
 * centericq Jabber protocol handling class
-* $Id: jabberhook.cc,v 1.54 2003/10/01 09:02:22 konst Exp $
+* $Id: jabberhook.cc,v 1.60 2003/11/22 19:14:33 konst Exp $
 *
 * Copyright (C) 2002 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -30,6 +30,7 @@
 #include "icqface.h"
 #include "imlogger.h"
 #include "eventmanager.h"
+#include "icqgroups.h"
 
 #include <libicq2000/userinfohelpers.h>
 
@@ -50,15 +51,6 @@ static void jidsplit(const string &jid, string &user, string &host, string &rest
     }
 }
 
-static string jidnormalize(const string &jid) {
-    string user, host, rest;
-    jidsplit(jid, user, host, rest);
-    if(host.empty()) host = "jabber.com";
-    user += (string) "@" + host;
-    if(!rest.empty()) user += (string) "/" + rest;
-    return user;
-}
-
 static string jidtodisp(const string &jid) {
     string user, host, rest;
     jidsplit(jid, user, host, rest);
@@ -69,14 +61,26 @@ static string jidtodisp(const string &jid) {
     return user;
 }
 
-#define KOI2UTF(x) siconv(x, conf.getrussian(jabber) ? "koi8-u" : conf.getdefcharset(), "utf8")
-#define UTF2KOI(x) siconv(x, "utf8", conf.getrussian(jabber) ? "koi8-u" : conf.getdefcharset())
+#define KOI2UTF(x) siconv(x, conf.getrussian(jabber) ? "koi8-u" : conf.getdefcharset(), "utf-8")
+#define UTF2KOI(x) siconv(x, "utf-8", conf.getrussian(jabber) ? "koi8-u" : conf.getdefcharset())
 
 // ----------------------------------------------------------------------------
 
 jabberhook jhook;
 
-jabberhook::jabberhook(): abstracthook(jabber), jc(0), flogged(false) {
+string jabberhook::jidnormalize(const string &jid) const {
+    if(find(agents.begin(), agents.end(), jid) != agents.end())
+	return jid;
+
+    string user, host, rest;
+    jidsplit(jid, user, host, rest);
+    if(host.empty()) host = "jabber.com";
+    user += (string) "@" + host;
+    if(!rest.empty()) user += (string) "/" + rest;
+    return user;
+}
+
+jabberhook::jabberhook(): abstracthook(jabber), jc(0), flogged(false), fonline(false) {
     fcapabs.insert(hookcapab::setaway);
     fcapabs.insert(hookcapab::fetchaway);
     fcapabs.insert(hookcapab::authrequests);
@@ -110,7 +114,9 @@ void jabberhook::connect() {
     auto_ptr<char> cjid(strdup(jid.c_str()));
     auto_ptr<char> cpass(strdup(acc.password.c_str()));
 
-    regmode = false;
+    regmode = flogged = fonline = false;
+
+    if(jc) delete jc;
 
     jc = jab_new(cjid.get(), cpass.get(), acc.port,
 	acc.additional["ssl"] == "1" ? 1 : 0);
@@ -123,6 +129,7 @@ void jabberhook::connect() {
 #endif
 
     if(jc->user) {
+	fonline = true;
 	jstate = STATE_CONNECTING;
 	statehandler(0, -1);
 	jab_start(jc);
@@ -130,8 +137,6 @@ void jabberhook::connect() {
 }
 
 void jabberhook::disconnect() {
-    jab_stop(jc);
-    jab_delete(jc);
     statehandler(jc, JCONN_STATE_OFF);
 }
 
@@ -158,8 +163,7 @@ void jabberhook::main() {
 
 	if(!jc || jc->state == JCONN_STATE_OFF) {
 	    face.log(_("+ [jab] unable to connect to the server"));
-	    jab_delete(jc);
-	    jc = 0;
+	    fonline = false;
 	}
     }
 
@@ -168,8 +172,6 @@ void jabberhook::main() {
 
     } else if(jc->state == JCONN_STATE_OFF || jc->fd == -1) {
 	statehandler(jc, JCONN_STATE_OFF);
-	jab_delete(jc);
-	jc = 0;
     }
 }
 
@@ -186,15 +188,15 @@ bool jabberhook::isoursocket(fd_set &rfds, fd_set &wfds, fd_set &efds) const {
 }
 
 bool jabberhook::online() const {
-    return (bool) jc;
+    return fonline;
 }
 
 bool jabberhook::logged() const {
-    return jc && flogged;
+    return fonline && flogged;
 }
 
 bool jabberhook::isconnecting() const {
-    return jc && !flogged;
+    return fonline && !flogged;
 }
 
 bool jabberhook::enabled() const {
@@ -281,13 +283,12 @@ void jabberhook::sendnewuser(const imcontact &ic, bool report) {
 
     if(!ischannel(ic)) {
 	auto_ptr<char> cjid(strdup(jidnormalize(ic.nickname).c_str()));
-	if(find(roster.begin(), roster.end(), cjid.get()) != roster.end())
+	if(roster.find(cjid.get()) != roster.end())
 	    return;
 
 	if(report)
 	    face.log(_("+ [jab] adding %s to the contacts"), ic.nickname.c_str());
 
-	roster.push_back(cjid.get());
 	x = jutil_presnew(JPACKET__SUBSCRIBE, cjid.get(), 0);
 	jab_send(jc, x);
 	xmlnode_free(x);
@@ -296,6 +297,18 @@ void jabberhook::sendnewuser(const imcontact &ic, bool report) {
 	y = xmlnode_get_tag(x, "query");
 	z = xmlnode_insert_tag(y, "item");
 	xmlnode_put_attrib(z, "jid", cjid.get());
+
+	roster[cjid.get()] = "";
+
+	if(c = clist.get(ic)) {
+	    vector<icqgroup>::const_iterator ig = find(groups.begin(), groups.end(), c->getgroupid());
+	    if(ig != groups.end()) {
+		z = xmlnode_insert_tag(z, "group");
+		xmlnode_insert_cdata(z, ig->getname().c_str(), (unsigned) -1);
+		roster[cjid.get()] = ig->getname();
+	    }
+	}
+
 	jab_send(jc, x);
 	xmlnode_free(x);
 
@@ -340,27 +353,38 @@ void jabberhook::removeuser(const imcontact &ic, bool report) {
 
     if(!ischannel(ic)) {
 	auto_ptr<char> cjid(strdup(jidnormalize(ic.nickname).c_str()));
-	vector<string>::iterator ir = find(roster.begin(), roster.end(), cjid.get());
 
-	if(ir == roster.end())
-	    return;
+	map<string, string>::iterator ir = roster.find(cjid.get());
 
-	if(report)
-	    face.log(_("+ [jab] removing %s from the contacts"), ic.nickname.c_str());
+	if(ir == roster.end()) return;
+	    else roster.erase(ir);
 
-	roster.erase(ir);
-	x = jutil_presnew(JPACKET__UNSUBSCRIBE, cjid.get(), 0);
+	if(find(agents.begin(), agents.end(), cjid.get()) != agents.end()) {
+	    if(report) face.log(_("+ [jab] unregistering from the %s agent"), cjid.get());
 
-	jab_send(jc, x);
-	xmlnode_free(x);
+	    x = jutil_iqnew(JPACKET__SET, NS_REGISTER);
+	    xmlnode_put_attrib(x, "to", cjid.get());
+	    y = xmlnode_get_tag(x, "query");
+	    xmlnode_insert_tag(y, "remove");
+	    jab_send(jc, x);
+	    xmlnode_free(x);
+
+	}
+
+	    if(report) face.log(_("+ [jab] removing %s from the contacts"), ic.nickname.c_str());
+
+	    x = jutil_presnew(JPACKET__UNSUBSCRIBE, cjid.get(), 0);
+	    jab_send(jc, x);
+	    xmlnode_free(x);
+
+	    x = jutil_iqnew(JPACKET__SET, NS_ROSTER);
+	    y = xmlnode_get_tag(x, "query");
+	    z = xmlnode_insert_tag(y, "item");
+	    xmlnode_put_attrib(z, "jid", cjid.get());
+	    xmlnode_put_attrib(z, "subscription", "remove");
+	    jab_send(jc, x);
+	    xmlnode_free(x);
 
-	x = jutil_iqnew(JPACKET__SET, NS_ROSTER);
-	y = xmlnode_get_tag(x, "query");
-	z = xmlnode_insert_tag(y, "item");
-	xmlnode_put_attrib(z, "jid", cjid.get());
-	xmlnode_put_attrib(z, "subscription", "remove");
-	jab_send(jc, x);
-	xmlnode_free(x);
     } else {
 	if(c = clist.get(ic)) {
 	    cname = ic.nickname.substr(1);
@@ -406,12 +430,24 @@ void jabberhook::setautostatus(imstatus st) {
 
 void jabberhook::requestinfo(const imcontact &ic) {
     if(isconnecting() || logged()) {
-	auto_ptr<char> cjid(strdup(jidnormalize(ic.nickname).c_str()));
-	xmlnode x = jutil_iqnew(JPACKET__GET, NS_VCARD);
-	xmlnode_put_attrib(x, "to", cjid.get());
-	xmlnode_put_attrib(x, "id", "VCARDreq");
-	jab_send(jc, x);
-	xmlnode_free(x);
+	vector<agent>::const_iterator ia = find(agents.begin(), agents.end(), ic.nickname);
+
+	if(ia != agents.end()) {
+	    icqcontact *c = clist.get(imcontact(ic.nickname, proto));
+	    if(c) {
+		c->setdispnick(ia->name);
+		c->setabout(ia->desc);
+	    }
+
+	} else {
+	    auto_ptr<char> cjid(strdup(jidnormalize(ic.nickname).c_str()));
+	    xmlnode x = jutil_iqnew(JPACKET__GET, NS_VCARD);
+	    xmlnode_put_attrib(x, "to", cjid.get());
+	    xmlnode_put_attrib(x, "id", "VCARDreq");
+	    jab_send(jc, x);
+	    xmlnode_free(x);
+
+	}
     }
 }
 
@@ -446,6 +482,8 @@ const string &serv, string &err) {
 	port = icqconf::defservers[proto].port;
     }
 
+    regmode = true;
+
     auto_ptr<char> cjid(strdup(jid.c_str()));
     auto_ptr<char> cpass(strdup(pass.c_str()));
 
@@ -453,8 +491,7 @@ const string &serv, string &err) {
 
     if(!jc->user) {
 	err = _("Wrong nickname given, cannot register");
-	jab_delete(jc);
-	jc = 0;
+	fonline = false;
 	return false;
     }
 
@@ -472,7 +509,6 @@ const string &serv, string &err) {
 	err = _("Unable to connect");
 
     } else {
-	regmode = true;
 	regdone = false;
 	regerr = "";
 
@@ -513,10 +549,13 @@ void jabberhook::setjabberstatus(imstatus st, const string &msg) {
 	    break;
     }
 
-    if(!msg.empty()) {
+    if(!conf.getourid(proto).additional["prio"].empty())
+	xmlnode_insert_cdata(xmlnode_insert_tag(x, "priority"),
+	    conf.getourid(proto).additional["prio"].c_str(), (unsigned) -1);
+
+    if(!msg.empty())
 	xmlnode_insert_cdata(xmlnode_insert_tag(x, "status"),
 	    msg.c_str(), (unsigned) -1);
-    }
 
     jab_send(jc, x);
     xmlnode_free(x);
@@ -551,15 +590,6 @@ void jabberhook::sendvisibility() {
     }
 }
 
-void jabberhook::checkinlist(imcontact ic) {
-    icqcontact *c = clist.get(ic);
-
-    if(c)
-    if(c->inlist())
-    if(find(roster.begin(), roster.end(), jidnormalize(ic.nickname)) != roster.end())
-	sendnewuser(ic, false);
-}
-
 vector<string> jabberhook::getservices(servicetype::enumeration st) const {
     vector<agent>::const_iterator ia = agents.begin();
     vector<string> r;
@@ -639,7 +669,7 @@ void jabberhook::gotagentinfo(xmlnode x) {
 
 		if(name == "instructions") ia->params[pt].instruction = data; else
 		if(name == "key") ia->params[pt].key = data; else
-		if(!name.empty()) {
+		if(!name.empty() && name != "registered") {
 		    ia->params[pt].paramnames.push_back(make_pair(name, data));
 		}
 	    }
@@ -711,6 +741,24 @@ void jabberhook::lookup(const imsearchparams &params, verticalmenu &dest) {
     }
 }
 
+void jabberhook::renamegroup(const string &oldname, const string &newname) {
+    map<string, string>::iterator ir = roster.begin();
+
+    while(ir != roster.end()) {
+	if(ir->second == oldname) {
+	    icqcontact *c = clist.get(imcontact(jidtodisp(ir->first), proto));
+	    if(c) {
+		updatecontact(c);
+		ir->second = newname;
+	    }
+	}
+
+	++ir;
+    }
+}
+
+// ----------------------------------------------------------------------------
+
 void jabberhook::gotsearchresults(xmlnode x) {
     xmlnode y, z;
     const char *jid, *nick, *first, *last, *email;
@@ -735,7 +783,7 @@ void jabberhook::gotsearchresults(xmlnode x) {
 
 	    if(nick) {
 		c->setnick(nick);
-		c->setdispnick(nick);
+		c->setdispnick(c->getnick());
 	    }
 
 	    if(first) cb.fname = first;
@@ -779,7 +827,7 @@ void jabberhook::gotloggedin() {
 }
 
 void jabberhook::gotroster(xmlnode x) {
-    xmlnode y;
+    xmlnode y, z;
     imcontact ic;
     icqcontact *c;
 
@@ -787,18 +835,20 @@ void jabberhook::gotroster(xmlnode x) {
 	const char *alias = xmlnode_get_attrib(y, "jid");
 	const char *sub = xmlnode_get_attrib(y, "subscription");
 	const char *name = xmlnode_get_attrib(y, "name");
-	const char *group = xmlnode_get_attrib(y, "group");
+	const char *group = 0;
+
+	z = xmlnode_get_tag(y, "group");
+	if(z) group = xmlnode_get_data(z);
 
 	if(alias) {
 	    ic = imcontact(jidtodisp(alias), proto);
-	    roster.push_back(jidnormalize(alias));
+	    clist.updateEntry(ic, group ? group : "");
 
-	    if(!(c = clist.get(ic))) {
-		c = clist.addnew(ic, false);
-		requestinfo(ic);
-	    }
+	    if(name)
+	    if(c = clist.get(ic))
+		c->setdispnick(UTF2KOI(name));
 
-	    if(name) c->setdispnick(name);
+	    roster[jidnormalize(alias)] = group ? group : "";
 	}
     }
 
@@ -860,8 +910,8 @@ void jabberhook::conferencecreate(const imcontact &confid, const vector<imcontac
 }
 
 static void vcput(xmlnode x, const string &name, const string &val) {
-    xmlnode_insert_cdata(xmlnode_insert_tag(x, KOI2UTF(name).c_str()),
-	val.c_str(), (unsigned int) -1);
+    xmlnode_insert_cdata(xmlnode_insert_tag(x, name.c_str()),
+	KOI2UTF(val).c_str(), (unsigned int) -1);
 }
 
 static void vcputphone(xmlnode x, const string &type, const string &place, const string &number) {
@@ -978,7 +1028,6 @@ void jabberhook::gotmessage(const string &type, const string &from, const string
 	if(!r.empty()) body.insert(0, r + ": ");
     }
 
-    checkinlist(ic);
     em.store(immessage(ic, imevent::incoming, UTF2KOI(body)));
 }
 
@@ -994,6 +1043,12 @@ void jabberhook::updatecontact(icqcontact *c) {
 	xmlnode_put_attrib(y, "jid", cjid.get());
 	xmlnode_put_attrib(y, "name", cname.get());
 
+	vector<icqgroup>::const_iterator ig = find(groups.begin(), groups.end(), c->getgroupid());
+	if(ig != groups.end()) {
+	    y = xmlnode_insert_tag(y, "group");
+	    xmlnode_insert_cdata(y, ig->getname().c_str(), (unsigned) -1);
+	}
+
 	jab_send(jc, x);
 	xmlnode_free(x);
     }
@@ -1128,7 +1183,7 @@ vector<icqcontact *> jabberhook::getneedsync() {
 	c = (icqcontact *) clist.at(i);
 
 	if(c->getdesc().pname == proto)
-	if(find(roster.begin(), roster.end(), c->getdesc().nickname) == roster.end())
+	if(roster.find(c->getdesc().nickname) == roster.end())
 	    r.push_back(c);
     }
 
@@ -1213,8 +1268,7 @@ void jabberhook::statehandler(jconn conn, int state) {
 	    if(previous_state != JCONN_STATE_OFF) {
 		logger.putourstatus(jhook.proto, jhook.getstatus(), jhook.ourstatus = offline);
 		face.log(_("+ [jab] disconnected"));
-		jhook.jc = 0;
-		jhook.flogged = false;
+		jhook.flogged = jhook.fonline = false;
 		jhook.roster.clear();
 		jhook.agents.clear();
 		clist.setoffline(jhook.proto);
@@ -1229,6 +1283,7 @@ void jabberhook::statehandler(jconn conn, int state) {
 	    break;
 
 	case JCONN_STATE_ON:
+	    if(jhook.regmode) jhook.fonline = true;
 	    break;
 
 	default:
@@ -1244,6 +1299,7 @@ void jabberhook::packethandler(jconn conn, jpacket packet) {
     string from, type, body, ns, id, u, h, s;
     imstatus ust;
     int npos;
+    bool isagent;
 
     jpacket_reset(packet);
 
@@ -1449,34 +1505,41 @@ void jabberhook::packethandler(jconn conn, jpacket packet) {
 	    } else {
 		icqcontact *c = clist.get(ic);
 
-		if(c) {
-		    if(c->getstatus() != ust) {
-			if(c->getstatus() == offline)
-			    jhook.awaymsgs[ic.nickname] = "";
+		if(c)
+		if(c->getstatus() != ust) {
+		    if(c->getstatus() == offline)
+			jhook.awaymsgs[ic.nickname] = "";
 
-			logger.putonline(c, c->getstatus(), ust);
-			c->setstatus(ust);
+		    logger.putonline(c, c->getstatus(), ust);
+		    c->setstatus(ust);
 
-			if(x = xmlnode_get_tag(packet->x, "status"))
-			if(p = xmlnode_get_data(x))
-			    jhook.awaymsgs[ic.nickname] = p;
-		    }
+		    if(x = xmlnode_get_tag(packet->x, "status"))
+		    if(p = xmlnode_get_data(x))
+			jhook.awaymsgs[ic.nickname] = p;
 		}
 	    }
 	    break;
 
 	case JPACKET_S10N:
+	    isagent = find(jhook.agents.begin(), jhook.agents.end(), from) != jhook.agents.end();
+
 	    if(type == "subscribe") {
-		em.store(imauthorization(ic, imevent::incoming,
-		    imauthorization::Request, _("The user wants to subscribe to your network presence updates")));
+		if(!isagent) {
+		    em.store(imauthorization(ic, imevent::incoming,
+			imauthorization::Request, _("The user wants to subscribe to your network presence updates")));
+
+		} else {
+		    auto_ptr<char> cfrom(strdup(from.c_str()));
+		    x = jutil_presnew(JPACKET__SUBSCRIBED, cfrom.get(), 0);
+		    jab_send(jhook.jc, x);
+		    xmlnode_free(x);
+		}
 
 	    } else if(type == "unsubscribe") {
 		auto_ptr<char> cfrom(strdup(from.c_str()));
-
 		x = jutil_presnew(JPACKET__UNSUBSCRIBED, cfrom.get(), 0);
 		jab_send(jhook.jc, x);
 		xmlnode_free(x);
-
 		em.store(imnotification(ic, _("The user has removed you from his contact list (unsubscribed you, using the Jabber language)")));
 
 	    }
