@@ -22,6 +22,9 @@ class rsshook: public abstracthook, public sigslot::has_slots<> {
 	    const string &name, const string &title,
 	    const string &postfix = "\n");
 
+    public:
+	static void parsedocument(const HTTPRequestEvent *rev, icqcontact *c);
+
     public:
 	rsshook();
 	~rsshook();
@@ -30,6 +33,7 @@ class rsshook: public abstracthook, public sigslot::has_slots<> {
 
 	void exectimers();
 	void main();
+	bool send(const imevent &ev);
 
 	void getsockets(fd_set &rfds, fd_set &wfds, fd_set &efds, int &hsocket) const;
 	bool isoursocket(fd_set &rfds, fd_set &wfds, fd_set &efds) const;
@@ -42,6 +46,9 @@ class rsshook: public abstracthook, public sigslot::has_slots<> {
 	void requestinfo(const imcontact &c);
 	void requestversion(const imcontact &c);
 	void ping(const imcontact &c);
+
+	void sendnewuser(const imcontact &ic);
+	void removeuser(const imcontact &ic);
 };
 
 extern rsshook rhook;
