@@ -1,7 +1,7 @@
 /*
 *
 * centericq yahoo! protocol handling class
-* $Id: yahoohook.cc,v 1.86 2003/10/02 09:07:15 konst Exp $
+* $Id: yahoohook.cc,v 1.98 2003/11/23 01:09:35 konst Exp $
 *
 * Copyright (C) 2003 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -37,7 +37,7 @@
 #include "accountmanager.h"
 #include "eventmanager.h"
 
-#include "libyahoo2.h"
+#include "yahoo2.h"
 
 #include <netdb.h>
 #include <sys/socket.h>
@@ -68,9 +68,9 @@ yahoohook::yahoohook() : abstracthook(yahoo), fonline(false), cid(0) {
     fcapabs.insert(hookcapab::setaway);
     fcapabs.insert(hookcapab::fetchaway);
     fcapabs.insert(hookcapab::synclist);
+    fcapabs.insert(hookcapab::directadd);
     fcapabs.insert(hookcapab::files);
     fcapabs.insert(hookcapab::conferencing);
-    fcapabs.insert(hookcapab::directadd);
     fcapabs.insert(hookcapab::conferencesaretemporary);
 
     pager_host[0] = pager_port[0] = filetransfer_host[0] =
@@ -122,6 +122,7 @@ void yahoohook::init() {
     c.ext_yahoo_webcam_closed = &webcam_closed;
     c.ext_yahoo_webcam_viewer = &webcam_viewer;
     c.ext_yahoo_webcam_data_request = &webcam_data_request;
+    c.ext_yahoo_search_result = &search_result;
     c.ext_yahoo_log = &log;
 
     yahoo_register_callbacks(&c);
@@ -246,16 +247,17 @@ bool yahoohook::isoursocket(fd_set &rs, fd_set &ws, fd_set &es) const {
 void yahoohook::disconnect() {
     if(online()) {
 	yahoo_logoff(cid);
-	disconnected();
     }
 }
 
 void yahoohook::disconnected() {
-    logger.putourstatus(proto, getstatus(), ourstatus = offline);
-    clist.setoffline(proto);
-    fonline = false;
-    face.log(_("+ [yahoo] disconnected"));
-    face.update();
+    if(logged()) {
+	logger.putourstatus(proto, getstatus(), ourstatus = offline);
+	clist.setoffline(proto);
+	fonline = false;
+	face.log(_("+ [yahoo] disconnected"));
+	face.update();
+    }
 }
 
 void yahoohook::exectimers() {
@@ -358,11 +360,10 @@ void yahoohook::sendnewuser(const imcontact &ic, bool report) {
 		if(report)
 		    face.log(_("+ [yahoo] adding %s to the contacts"), ic.nickname.c_str());
 
-		string groupname = "centericq";
 		vector<icqgroup>::const_iterator ig = find(groups.begin(), groups.end(), clist.get(ic)->getgroupid());
-		if(ig != groups.end()) groupname = ig->getname();
-
-		yahoo_add_buddy(cid, ic.nickname.c_str(), groupname.c_str());
+		if(ig != groups.end()) {
+		    yahoo_add_buddy(cid, ic.nickname.c_str(), ig->getname().c_str());
+		}
 	    }
 	}
     }
@@ -384,16 +385,11 @@ void yahoohook::removeuser(const imcontact &ic, bool report) {
 	    const YList *buddies = yahoo_get_buddylist(cid);
 	    const YList *bud = 0;
 
-	    for(bud = buddies; bud; ) {
-		if(ic.nickname == static_cast<yahoo_buddy *>(bud->data)->id) {
+	    for(bud = buddies; bud; bud = y_list_next(bud)) {
+		if(ic.nickname == ((yahoo_buddy *) bud->data)->id)
 		    yahoo_remove_buddy(cid,
-			static_cast<yahoo_buddy *>(bud->data)->id,
-			static_cast<yahoo_buddy *>(bud->data)->group);
-
-		    bud = buddies;
-		} else {
-		    bud = y_list_next(bud);
-		}
+			((yahoo_buddy *) bud->data)->id,
+			((yahoo_buddy *) bud->data)->group);
 	    }
 	} else {
 	    if(report)
@@ -479,18 +475,19 @@ imstatus yahoohook::getstatus() const {
 }
 
 void yahoohook::requestinfo(const imcontact &ic) {
+    requestfromfound(ic);
+
     icqcontact *c = clist.get(ic);
+    if(!c) c = clist.get(contactroot);
 
-    if(c) {
-	icqcontact::moreinfo m = c->getmoreinfo();
-	icqcontact::basicinfo b = c->getbasicinfo();
+    icqcontact::moreinfo m = c->getmoreinfo();
+    icqcontact::basicinfo b = c->getbasicinfo();
 
-	m.homepage = "http://profiles.yahoo.com/" + ic.nickname;
-	b.email = ic.nickname + "@yahoo.com";
+    m.homepage = "http://profiles.yahoo.com/" + ic.nickname;
+    b.email = ic.nickname + "@yahoo.com";
 
-	c->setmoreinfo(m);
-	c->setbasicinfo(b);
-    }
+    c->setmoreinfo(m);
+    c->setbasicinfo(b);
 }
 
 void yahoohook::userstatus(const string &nick, int st, const string &message, bool away) {
@@ -554,12 +551,22 @@ vector<icqcontact *> yahoohook::getneedsync() {
     return r;
 }
 
-string yahoohook::decode(const string &text, bool utf) {
-    if(utf)
-	return siconv(text, "utf8",
-	    conf.getrussian(proto) ? "koi8-u" : conf.getdefcharset());
+string yahoohook::decode(string text, bool utf) {
+    int npos, mpos;
 
-    return rushtmlconv("wk", text);
+    if(utf) text = siconv(text, "utf-8",
+	conf.getrussian(proto) ? "koi8-u" : conf.getdefcharset());
+
+    text = rushtmlconv("wk", text);
+
+    while((npos = text.find("\e[")) != -1) {
+	if((mpos = text.substr(npos).find("m")) == -1)
+	    mpos = text.size()-npos-1;
+
+	text.erase(npos, mpos+1);
+    }
+
+    return text;
 }
 
 bool yahoohook::knowntransfer(const imfile &fr) const {
@@ -588,10 +595,24 @@ void yahoohook::lookup(const imsearchparams &params, verticalmenu &dest) {
     icqcontact *c;
     vector<string>::const_iterator i;
 
-    searchdest = &dest;
-    room = params.room.substr(1);
+    while(!foundguys.empty()) {
+	delete foundguys.back();
+	foundguys.pop_back();
+    }
 
-    if(!params.room.empty()) {
+    searchonlineonly = params.onlineonly;
+    searchdest = &dest;
+
+    if(!params.kwords.empty()) {
+	yahoo_search(cid, YAHOO_SEARCH_KEYWORD, decode(params.kwords, false).c_str(),
+		params.gender, YAHOO_AGERANGE_NONE, params.photo ? 1 : 0, 1);
+
+    } else if(!params.firstname.empty()) {
+	yahoo_search(cid, YAHOO_SEARCH_NAME, decode(params.firstname, false).c_str(),
+		params.gender, YAHOO_AGERANGE_NONE, params.photo ? 1 : 0, 1);
+
+    } else if(!params.room.empty()) {
+	room = params.room.substr(1);
 	i = confmembers[room].begin();
 
 	while(i != confmembers[room].end()) {
@@ -601,15 +622,15 @@ void yahoohook::lookup(const imsearchparams &params, verticalmenu &dest) {
 
 	    ++i;
 	}
+
+	face.findready();
+	face.log(_("+ [yahoo] members list fetching finished, %d found"),
+	    searchdest->getcount());
+
+	searchdest->redraw();
+	searchdest = 0;
+
     }
-
-    face.findready();
-
-    face.log(_("+ [yahoo] members list fetching finished, %d found"),
-	searchdest->getcount());
-
-    searchdest->redraw();
-    searchdest = 0;
 }
 
 void yahoohook::conferencecreate(const imcontact &confid, const vector<imcontact> &lst) {
@@ -658,6 +679,39 @@ void yahoohook::checkinlist(imcontact ic) {
 	sendnewuser(ic, false);
 }
 
+void yahoohook::updatecontact(icqcontact *c) {
+    if(logged() && conf.getgroupmode() != icqconf::nogroups) {
+	bool found = false;
+	const YList *buddies = yahoo_get_buddylist(cid);
+	string newgroupname = groups.getname(c->getgroupid());
+
+	for(const YList *bud = buddies; bud; ) {
+	    yahoo_buddy *yb = (yahoo_buddy *) bud->data;
+
+	    if(c->getdesc().nickname == yb->id) {
+		if(!found) {
+		    if(newgroupname != yb->group)
+			yahoo_change_buddy_group(cid, yb->id, yb->group, newgroupname.c_str());
+
+		    found = true;
+		} else {
+		    yahoo_remove_buddy(cid, yb->id, yb->group);
+		}
+	    }
+
+	    bud = y_list_next(bud);
+	}
+    }
+}
+
+void yahoohook::renamegroup(const string &oldname, const string &newname) {
+    if(logged()) {
+	string tempname = oldname + "___" + i2str(getpid()) + "_temp";
+	yahoo_group_rename(cid, oldname.c_str(), tempname.c_str());
+	yahoo_group_rename(cid, tempname.c_str(), newname.c_str());
+    }
+}
+
 // ----------------------------------------------------------------------------
 
 void yahoohook::login_response(int id, int succ, char *url) {
@@ -668,75 +722,43 @@ void yahoohook::login_response(int id, int succ, char *url) {
 	    yhook.flogged = true;
 	    logger.putourstatus(yahoo, offline, yhook.ourstatus = yhook.manualstatus);
 	    face.log(_("+ [yahoo] logged in"));
-
-	    for(int i = 0; i < clist.count; i++) {
-		icqcontact *c = (icqcontact *) clist.at(i);
-		imcontact ic = c->getdesc();
-
-		if(ic.pname == yahoo)
-		if(!c->inlist()) {
-		    yhook.sendnewuser(ic);
-		}
-	    }
-
 	    time(&yhook.timer_refresh);
 	    yhook.setautostatus(yhook.manualstatus);
 	    break;
 
 	case YAHOO_LOGIN_PASSWD:
-	    yhook.fonline = false;
+	    yhook.fonline = yhook.fonline = false;
+	    yahoo_close(yhook.cid);
 	    face.log(_("+ [yahoo] cannot login: username and password mismatch"));
 	    break;
 
 	case YAHOO_LOGIN_LOCK:
-	    yhook.fonline = false;
+	    yhook.fonline = yhook.fonline = false;
+	    yahoo_close(yhook.cid);
 	    face.log(_("+ [yahoo] cannot login: the account has been blocked"));
 	    face.log(_("+ to reactivate visit %s"), url);
 	    break;
 
 	case YAHOO_LOGIN_DUPL:
 	    face.log(_("+ [yahoo] another logon detected"));
+	    yahoo_logoff(yhook.cid);
+	    break;
+
+	case YAHOO_LOGIN_SOCK:
 	    yhook.disconnected();
 	    break;
     }
 
-    if(succ != YAHOO_LOGIN_OK) {
-	yhook.cid = -1;
-    }
-
     face.update();
 }
 
 void yahoohook::got_buddies(int id, YList *buds) {
-    vector<string> nicks;
-    vector<string>::iterator in;
-
-    icqconf::imaccount acc = conf.getourid(yahoo);
-    icqcontact *c;
     const YList *buddy;
 
-    int i;
-
     for(buddy = buds; buddy; buddy = y_list_next(buddy)) {
-	yahoo_buddy *bud = static_cast<yahoo_buddy*>(buddy->data);
-	string id = bud->id;
-
-	if(find(nicks.begin(), nicks.end(), id) == nicks.end()) {
-	    nicks.push_back(id);
-	}
+	yahoo_buddy *bud = static_cast<yahoo_buddy *>(buddy->data);
+	clist.updateEntry(imcontact(bud->id, yahoo), bud->group ? bud->group : "");
     }
-
-    for(i = 0; i < clist.count; i++) {
-	c = (icqcontact *) clist.at(i);
-
-	if(c->getdesc().pname == yahoo && !ischannel(c)) {
-	    in = find(nicks.begin(), nicks.end(), c->getdesc().nickname);
-	    if(in != nicks.end()) nicks.erase(in);
-	}
-    }
-
-    for(in = nicks.begin(); in != nicks.end(); ++in)
-	clist.addnew(imcontact(*in, yahoo), false);
 }
 
 void yahoohook::got_identities(int id, YList *buds) {
@@ -758,6 +780,76 @@ void yahoohook::got_im(int id, char *who, char *msg, long tm, int stat, int utf8
     }
 }
 
+void yahoohook::search_result(int id, struct yahoo_search_result *yr) {
+    yahoo_found_contact *fc;
+    icqcontact *c;
+    YList *ir;
+    string sg, line;
+
+    if(!yhook.searchdest)
+	return;
+
+    for(ir = yr->contacts; ir; ir = ir->next) {
+	fc = (yahoo_found_contact *) ir->data;
+
+	if(yhook.searchonlineonly && !fc->online)
+	    continue;
+
+	c = new icqcontact(imcontact(fc->id, yahoo));
+
+	icqcontact::basicinfo binfo = c->getbasicinfo();
+	icqcontact::moreinfo minfo = c->getmoreinfo();
+
+	if(!fc->id || !fc->gender)
+	    continue;
+
+	c->setnick(fc->id);
+	c->setdispnick(c->getnick());
+
+	sg = up(fc->gender);
+	if(sg == "MALE") minfo.gender = genderMale;
+	else if(sg == "FEMALE") minfo.gender = genderFemale;
+
+	minfo.age = fc->age;
+	if(fc->location) binfo.street = fc->location;
+
+	line = (fc->online ? "o " : "  ") + c->getnick();
+
+	if(fc->age || fc->location || strlen(fc->gender) >= 4) {
+	    line += " <";
+	    if(fc->age) line += i2str(fc->age);
+
+	    if(strlen(fc->gender) >= 4) {
+		if(fc->age) line += ", ";
+		line += fc->gender;
+	    }
+
+	    if(fc->location && strlen(fc->location)) {
+		if(fc->age || strlen(fc->gender) >= 4) line += ", ";
+		line += fc->location;
+	    }
+
+	    line += ">";
+	}
+
+	c->setbasicinfo(binfo);
+	c->setmoreinfo(minfo);
+
+	yhook.foundguys.push_back(c);
+	yhook.searchdest->additem(conf.getcolor(cp_clist_yahoo), c, line);
+    }
+
+    yhook.searchdest->redraw();
+
+    if(yr->start+yr->found >= yr->total) {
+	face.findready();
+	face.log(_("+ [yahoo] search finished, %d found"), yhook.foundguys.size());
+	yhook.searchdest = 0;
+    } else {
+	yahoo_search_again(yhook.cid);
+    }
+}
+
 void yahoohook::got_conf_invite(int id, char *who, char *room, char *msg, YList *members) {
     icqconf::imaccount acc = conf.getourid(yahoo);
     string confname = (string) "#" + room, inviter, text;
@@ -1013,7 +1105,7 @@ void yahoohook::chat_message(int id, char *who, char *room, char *msg, int msgty
 void yahoohook::rejected(int id, char *who, char *msg) {
 }
 
-void yahoohook::got_webcam_image(int id, const char * who, unsigned char *image, unsigned int image_size, unsigned int real_size, unsigned int timestamp) {
+void yahoohook::got_webcam_image(int id, const char * who, const unsigned char *image, unsigned int image_size, unsigned int real_size, unsigned int timestamp) {
 }
 
 void yahoohook::webcam_invite(int id, char *from) {
