@@ -6,6 +6,8 @@
 #ifdef BUILD_YAHOO
 
 #include "icqconf.h"
+
+#define USE_STRUCT_CALLBACKS
 #include "yahoo2_callbacks.h"
 
 class yahoohook: public abstracthook {
@@ -39,7 +41,7 @@ class yahoohook: public abstracthook {
 	map<imfile, string> fvalid;
 	map<string, string> awaymessages;
 
-	bool fonline, flogged;
+	bool fonline, flogged, searchonlineonly;
 	map<string, vector<string> > confmembers;
 	imstatus ourstatus;
 	int cid;
@@ -65,13 +67,14 @@ class yahoohook: public abstracthook {
 	static void error(int id, char *err, int fatal);
 	static void got_ignore(int id, YList * igns);
 	static void got_cookies(int id);
+	static void search_result(int id, struct yahoo_search_result *yr);
 	static void chat_cat_xml(int id, char *xml);
 	static void chat_join(int id, char *room, char *topic, YList *members);
 	static void chat_userjoin(int id, char *room, struct yahoo_chat_member *who);
 	static void chat_userleave(int id, char *room, char *who);
 	static void chat_message(int id, char *who, char *room, char *msg, int msgtype, int utf8);
 	static void rejected(int id, char *who, char *msg);
-	static void got_webcam_image(int id, const char * who, unsigned char *image, unsigned int image_size, unsigned int real_size, unsigned int timestamp);
+	static void got_webcam_image(int id, const char * who, const unsigned char *image, unsigned int image_size, unsigned int real_size, unsigned int timestamp);
 	static void webcam_invite(int id, char *from);
 	static void webcam_invite_reply(int id, char *from, int accept);
 	static void webcam_closed(int id, char *who, int reason);
@@ -90,7 +93,7 @@ class yahoohook: public abstracthook {
 	static struct tm *timestamp();
 	static imstatus yahoo2imstatus(int status);
 
-	string decode(const string &text, bool utf);
+	string decode(string text, bool utf);
 
 	YList *getmembers(const string &room);
 	void userstatus(const string &nick, int st, const string &message, bool away);
@@ -140,6 +143,9 @@ class yahoohook: public abstracthook {
 
 	void requestawaymsg(const imcontact &ic);
 	void conferencecreate(const imcontact &confid, const vector<imcontact> &lst);
+
+	void updatecontact(icqcontact *c);
+	void renamegroup(const string &oldname, const string &newname);
 };
 
 extern yahoohook yhook;
