@@ -1,7 +1,7 @@
 /*
 *
 * centericq single IM contact class
-* $Id: icqcontact.cc,v 1.84 2003/10/01 23:01:52 konst Exp $
+* $Id: icqcontact.cc,v 1.88 2003/11/05 14:54:26 konst Exp $
 *
 * Copyright (C) 2001,2002 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -200,8 +200,8 @@ void icqcontact::save() {
 		    (background.size() > 0 ? *(background.begin()+0) : "") << endl <<
 		    (background.size() > 1 ? *(background.begin()+1) : "") << endl <<
 		    (background.size() > 2 ? *(background.begin()+2) : "") << endl <<
-		    endl <<
-		    endl <<
+		    minfo.checkfreq << endl <<
+		    minfo.checklast << endl <<
 		    lastip << endl <<
 		    tosane(dispnick) << endl <<
 		    lastseen << endl <<
@@ -292,8 +292,8 @@ void icqcontact::load() {
 		case 39: if(strlen(buf)) background.push_back(buf); break;
 		case 40: if(strlen(buf)) background.push_back(buf); break;
 		case 41: if(strlen(buf)) background.push_back(buf); break;
-		case 42: break;
-		case 43: break;
+		case 42: minfo.checkfreq = atoi(buf); break;
+		case 43: minfo.checklast = atoi(buf); break;
 		case 44: lastip = buf; break;
 		case 45: dispnick = buf; break;
 		case 46: lastseen = strtoul(buf, 0, 0); break;
@@ -449,7 +449,7 @@ void icqcontact::scanhistory() {
     }
 }
 
-void icqcontact::setstatus(imstatus fstatus) {
+void icqcontact::setstatus(imstatus fstatus, bool reflect) {
     if(status != fstatus) {
 	if(!ischannel(cdesc)) {
 	    if(status == offline) {
@@ -457,7 +457,7 @@ void icqcontact::setstatus(imstatus fstatus) {
 		playsound(imevent::online);
 	    }
 
-	} else {
+	} else if(reflect) {
 	    abstracthook &h = gethook(cdesc.pname);
 	    if(fstatus == offline) h.removeuser(cdesc);
 	    else h.sendnewuser(cdesc);
@@ -675,9 +675,12 @@ string icqcontact::getpostponed() const {
     return postponed;
 }
 
-void icqcontact::setgroupid(int agroupid) {
+void icqcontact::setgroupid(int agroupid, bool reflect) {
     groupid = agroupid;
     modified = true;
+
+    if(reflect)
+	gethook(cdesc.pname).updatecontact(this);
 }
 
 int icqcontact::getgroupid() const {
