@@ -12,7 +12,7 @@
 #include "imevents.h"
 
 enum imgender {
-    genderUnspec,
+    genderUnspec = 0,
     genderMale,
     genderFemale,
     imgender_size
@@ -35,7 +35,7 @@ class icqcontact {
 	    moreinfo():
 		gender(genderUnspec), age(0), birth_day(0),
 		birth_month(0), birth_year(0), lang1(0), lang2(0), lang3(0),
-		timezone(0) {};
+		timezone(0), checkfreq(0), checklast(0) {};
 
 	    unsigned char age;
 	    imgender gender;
@@ -46,6 +46,8 @@ class icqcontact {
 
 	    string strbirthdate() const;
 	    string strtimezone() const;
+
+	    int checkfreq, checklast;
 	};
 
 	struct workinfo {
@@ -85,7 +87,7 @@ class icqcontact {
 	icqcontact(imcontact adesc);
 	~icqcontact();
 
-	void setstatus(imstatus fstatus);
+	void setstatus(imstatus fstatus, bool reflect = true);
 	void setlastread(time_t flastread);
 	void setlastseen();
 
@@ -147,7 +149,7 @@ class icqcontact {
 	int gethistoffset() const;
 	void sethistoffset(int aoffset);
 
-	void setgroupid(int agroupid);
+	void setgroupid(int agroupid, bool reflect = true);
 	int getgroupid() const;
 
 	const imcontact getdesc() const;
