@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class, dialogs related part
-* $Id: icqdialogs.cc,v 1.126 2003/10/01 00:27:45 konst Exp $
+* $Id: icqdialogs.cc,v 1.133 2003/11/22 19:14:32 konst Exp $
 *
 * Copyright (C) 2001,2002 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -30,6 +30,7 @@
 #include "icqmlist.h"
 #include "icqgroups.h"
 #include "abstracthook.h"
+#include "ljhook.h"
 
 #include <libicq2000/userinfohelpers.h>
 #include <libicq2000/constants.h>
@@ -371,7 +372,22 @@ bool icqface::finddialog(imsearchparams &s, findsubject subj) {
 	    }
 	}
 
-	if((subj == fsuser) && s.pname == msn && s.nick.empty()) {
+	if((subj == fsuser) && s.pname == yahoo && s.nick.empty()) {
+	    i = tree.addnode(_(" Details "));
+
+	    if(s.kwords.empty()) tree.addleaff(i, 0, 27, _(" Name : %s "), s.firstname.c_str());
+	    if(s.firstname.empty()) tree.addleaff(i, 0, 29, _(" Keywords : %s "), s.kwords.c_str());
+
+	    i = tree.addnode(_(" Options "));
+
+	    tree.addleaff(i, 0, 17, _(" Gender : %s "), strgender(s.gender));
+	    tree.addleaff(i, 0, 15, _(" Age range : %s "), stragerange(s.agerange));
+	    tree.addleaff(i, 0, 35, _(" Users with photos only : %s "), stryesno(s.photo));
+	    tree.addleaff(i, 0, 25, _(" Look for online only : %s "), stryesno(s.onlineonly));
+	}
+
+	if((subj == fsuser) && s.nick.empty()
+	&& (s.pname == msn || s.pname == livejournal)) {
 	    i = tree.addnode(_(" Show users who have you on their list "));
 	    tree.addleaff(i, 0, 30, " %s ", stryesno(s.reverse));
 	}
@@ -478,6 +494,7 @@ bool icqface::finddialog(imsearchparams &s, findsubject subj) {
 		    case 32: s.password = inputstr(_("Password: "), s.password, '*'); break;
 		    case 33: s.url = inputstr(_("URL: "), s.url); break;
 		    case 34: s.checkfrequency = atol(inputstr(_("Check frequency: "), strint(s.checkfrequency)).c_str()); break;
+		    case 35: s.photo = !s.photo;
 		}
 
 		if(i >= 100) {
@@ -631,7 +648,7 @@ void icqface::gendetails(treeview *tree, icqcontact *c) {
     if(passinfo.pname == rss) {
 	i = tree->addnode(_(" Feed Parameters "));
 	tree->addleaff(i, 0, 48, _(" XML export URL : %s "), wi.homepage.c_str());
-	tree->addleaff(i, 0, 49, _(" Check frequency (minutes) : %lu "), mi.birth_day);
+	tree->addleaff(i, 0, 49, _(" Check frequency (minutes) : %lu "), mi.checkfreq);
     }
 
     if(capab.count(hookcapab::changeabout))
@@ -804,7 +821,7 @@ bool icqface::updatedetails(icqcontact *c, protocolname upname) {
 			ri.password = "";
 		    break;
 		case 48: wi.homepage = inputstr(_("URL: "), wi.homepage); break;
-		case 49: mi.birth_day = atol(inputstr(_("Check frequency: "), strint(mi.birth_day)).c_str()); break;
+		case 49: mi.checkfreq = atol(inputstr(_("Check frequency: "), strint(mi.checkfreq)).c_str()); break;
 		default:
 		    if(citem >= 100) {
 			vector<pair<string, string> >::iterator ifp = ri.params.begin()+citem-100;
@@ -1317,7 +1334,7 @@ void icqface::selectproto(bool prots[], bool irss) {
 	if(gethook(pname).getCapabs().count(hookcapab::nochat))
 	    continue;
 
-	if(pname == infocard)
+	if(!gethook(pname).enabled())
 	    continue;
 
 	if(!conf.getourid(pname).empty() || irss)
@@ -1458,6 +1475,8 @@ int icqface::groupmanager(const string &text, bool sel) {
 		if(n) {
 		    i = groups.begin()+n-1;
 		    gname = inputstr(_("New name for the group: "), i->getname());
+
+		    if(input.getlastkey() != KEY_ESC)
 		    if(!gname.empty()) {
 			i->rename(gname);
 			touched = true;
@@ -1660,3 +1679,171 @@ transferstatus st, int btotal, int bdone) {
     if(bdone) i->bdone = bdone;
     i->status = st;
 }
+
+void icqface::invokelist(string &s, vector<string> &v, const string &def, textwindow *w) {
+    int delems = (int) ((w->y2-w->y1)/2);
+    int vmax = v.size() > delems ? delems : v.size();
+    if(vmax < 2) return;
+    vmax++;
+
+    verticalmenu m(conf.getcolor(cp_dialog_menu), conf.getcolor(cp_dialog_selected));
+    m.setwindow(textwindow(w->x1, w->y2-vmax, w->x1+30, w->y2, conf.getcolor(cp_dialog_menu)));
+    m.idle = &menuidle;
+
+    vector<string>::const_iterator iv = v.begin();
+    while(iv != v.end()) {
+	string cs = *iv;
+	if(cs.empty()) cs = def;
+	m.additem((string) " " + cs);
+	if(cs == s) m.setpos(iv-v.begin());
+	++iv;
+    }
+
+    int i = m.open();
+    m.close();
+
+    if(i) s = v[i-1];
+}
+
+bool icqface::setljparams(imxmlevent *ev) {
+    bool r = false;
+
+#ifdef BUILD_LJ
+
+    #define LJP_LIST(x, l, d) \
+	tmp = ev->getfield(x); \
+	invokelist(tmp, l, d, db.getwindow()); \
+	ev->setfield(x, tmp);
+
+    #define LJP_STR(x, m) \
+	ev->setfield(x, inputstr(m, ev->getfield(x)));
+
+    #define LJP_BOOL(x) \
+	ev->setfield(x, ev->getfield(x) == "1" ? "" : "1"); 
+
+    int i, n, b;
+    dialogbox db;
+
+    vector<string> journals, moods, pictures;
+    vector<string>::iterator im;
+    string tmp;
+    bool custmood;
+
+    static vector<string> snames, svalues;
+
+    journals = lhook.getjournals();
+    pictures = lhook.getpictures();
+    moods = lhook.getmoods();
+
+    ev->setfield("_eventkind", "posting");
+
+    if(ev->field_empty("journal") && !journals.empty())
+	ev->setfield("journal", journals.front());
+
+    if(ev->field_empty("mood") && !moods.empty())
+	ev->setfield("mood", moods.front());
+
+    if(ev->field_empty("picture") && !pictures.empty())
+	ev->setfield("picture", pictures.front());
+
+    if(ev->field_empty("security"))
+	ev->setfield("security", "public");
+
+    if(snames.empty()) {
+	snames.push_back(_("public (visible to all)"));
+	svalues.push_back("public");
+	snames.push_back(_("private"));
+	svalues.push_back("private");
+	snames.push_back(_("friends only"));
+	svalues.push_back("usemask");
+    }
+
+    textwindow w(0, 0, sizeDlg.width, sizeDlg.height, conf.getcolor(cp_dialog_frame), TW_CENTERED);
+    w.set_title(conf.getcolor(cp_dialog_highlight), _(" LiveJournal posting: attributes "));
+    db.setwindow(&w, false);
+
+    db.settree(new treeview(conf.getcolor(cp_dialog_text),
+	conf.getcolor(cp_dialog_selected), conf.getcolor(cp_dialog_highlight),
+	conf.getcolor(cp_dialog_text)));
+
+    db.setbar(new horizontalbar(conf.getcolor(cp_dialog_text), conf.getcolor(cp_dialog_selected),
+	_("Change"), _("Detect music"), _("Post"), _("cAncel"), 0));
+
+    db.addautokeys();
+    db.idle = &dialogidle;
+
+    blockmainscreen();
+    treeview &t = *db.gettree();
+
+    for(bool fin = false; !fin && !r; ) {
+	t.clear();
+
+	i = t.addnode(_(" General "));
+	t.addleaff(i, 0, 10, _(" Post to journal : %s "), ev->getfield("journal").c_str());
+	t.addleaff(i, 0, 11, _(" Subject : %s "), ev->getfield("subject").c_str());
+
+	vector<string>::iterator is = find(svalues.begin(), svalues.end(), ev->getfield("security"));
+	if(is == svalues.end()) is = svalues.begin();
+	tmp = is != svalues.end() ? snames[is-svalues.begin()] : "";
+	t.addleaff(i, 0, 12, _(" Security : %s "), tmp.c_str());
+
+	i = t.addnode(_(" Fancy stuff "));
+
+	custmood = find(moods.begin(), moods.end(), ev->getfield("mood")) == moods.end() || ev->getfield("mood").empty();
+	t.addleaff(i, 0, 20, _(" Mood : %s "), custmood ? _("(none/custom)") : ev->getfield("mood").c_str());
+	if(custmood) t.addleaff(i, 0, 23, _(" Custom mood : %s "), ev->getfield("mood").c_str());
+
+	t.addleaff(i, 0, 21, _(" Music : %s "), ev->getfield("music").c_str());
+	t.addleaff(i, 0, 22, _(" Picture : %s "), ev->getfield("picture").empty() ? _("(default)") : ev->getfield("picture").c_str());
+
+	i = t.addnode(_(" Options "));
+	t.addleaff(i, 0, 30, _(" Disable auto-formatting : %s "), stryesno(ev->getfield("preformatted") == "1"));
+	t.addleaff(i, 0, 31, _(" Disable sending comments by e-mail : %s "), stryesno(ev->getfield("noemail") == "1"));
+	t.addleaff(i, 0, 32, _(" Disallow comments : %s "), stryesno(ev->getfield("nocomments") == "1"));
+	t.addleaff(i, 0, 33, _(" Backdated entry : %s "), stryesno(ev->getfield("backdated") == "1"));
+
+	fin = !db.open(n, b, (void **) &n);
+
+	if(!fin) {
+	    if(b == 0) {
+		switch(n) {
+		    case 10: LJP_LIST("journal", journals, ""); break;
+		    case 11: LJP_STR("subject", _("Posting subject: ")); break;
+		    case 12:
+			tmp = snames[find(svalues.begin(), svalues.end(), ev->getfield("security"))-svalues.begin()];
+			invokelist(tmp, snames, "", db.getwindow());
+			tmp = svalues[find(snames.begin(), snames.end(), tmp)-snames.begin()];
+			ev->setfield("security", tmp);
+			break;
+
+		    case 20: LJP_LIST("mood", moods, _("(none/custom)")); break;
+		    case 21: LJP_STR("music", _("Currently playing: ")); break;
+		    case 22: LJP_LIST("picture", pictures, _("(default)")); break;
+		    case 23: LJP_STR("mood", _("Current mood: ")); break;
+		    case 30: LJP_BOOL("preformatted"); break;
+		    case 31: LJP_BOOL("noemail"); break;
+		    case 32: LJP_BOOL("nocomments"); break;
+		    case 33: LJP_BOOL("backdated"); break;
+		}
+
+	    } else if(b == 1) {
+		ev->setfield("music", conf.execaction("detectmusic"));
+
+	    } else if(b == 2) {
+		r = true;
+
+	    } else if(b == 3) {
+		r = false;
+		fin = true;
+
+	    }
+	}
+    }
+
+    db.close();
+    unblockmainscreen();
+
+#endif
+
+    return r;
+}
