@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class
-* $Id: icqface.cc,v 1.194 2003/09/30 11:38:41 konst Exp $
+* $Id: icqface.cc,v 1.202 2003/11/23 01:09:34 konst Exp $
 *
 * Copyright (C) 2001-2003 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -222,7 +222,7 @@ void icqface::showtopbar() {
 
     attrset(conf.getcolor(cp_status));
     mvhline(0, 0, ' ', COLS);
-    mvprintw(0, 2, _("CENTERICQ %s   UNSENT: %lu"), VERSION, em.getunsentcount());
+    mvprintw(0, 2, _("CENTERICQ %s  UNSENT: %lu"), VERSION, em.getunsentcount());
     mvprintw(0, COLS-buf.size()-2, "%s", buf.c_str());
 }
 
@@ -367,6 +367,7 @@ int icqface::contextmenu(icqcontact *c) {
 	actions.push_back(ACT_REMOVE);
 	actions.push_back(ACT_IGNORE);
 	actions.push_back(ACT_INFO);
+	actions.push_back(ACT_EDITUSER);
 	actions.push_back(ACT_PING);
 
 	if(conf.getgroupmode() != icqconf::nogroups)
@@ -472,8 +473,12 @@ icqcontact *icqface::mainloop(int &action) {
 	    }                
 
 	    if(c) {
-		if(action == ACT_MSG && c->getdesc().pname == infocard && !c->hasevents())
-		    action = ACT_SMS;
+		if(action == ACT_MSG && !c->hasevents()) {
+		    switch(c->getdesc().pname) {
+			case infocard: action = ACT_SMS; break;
+			case livejournal: action = ACT_LJ; break;
+		    }
+		}
 
 		if(action == ACT_MENU)
 		if(!(action = contextmenu(c))) continue;
@@ -737,20 +742,26 @@ bool icqface::findresults(const imsearchparams &sp, bool fauto) {
     saveworkarea();
     clearworkarea();
 
+    abstracthook &h = gethook(sp.pname);
+
     db.setwindow(new textwindow(sizeWArea.x1+1, sizeWArea.y1+2, sizeWArea.x2,
 	sizeWArea.y2, conf.getcolor(cp_main_text), TW_NOBORDER));
     db.setmenu(new verticalmenu(conf.getcolor(cp_main_menu),
 	conf.getcolor(cp_main_selected)));
 
-    db.setbar(new horizontalbar(conf.getcolor(cp_main_highlight),
-	conf.getcolor(cp_main_selected), _("Details"), _("Message"), _("Add"),
-	fauto ? 0 : _("New search"), 0));
+    if(!h.getCapabs().count(hookcapab::nochat)) {
+	db.setbar(new horizontalbar(conf.getcolor(cp_main_highlight),
+	    conf.getcolor(cp_main_selected), _("Details"), _("Message"),
+	    _("Add"), fauto ? 0 : _("New search"), 0));
+    } else {
+	db.setbar(new horizontalbar(conf.getcolor(cp_main_highlight),
+	    conf.getcolor(cp_main_selected), _("Details"), _("Add"),
+	    fauto ? 0 : _("New search"), 0));
+    }
 
     db.addautokeys();
     db.redraw();
 
-    abstracthook &h = gethook(sp.pname);
-
     if(!sp.nick.empty() && h.getCapabs().count(hookcapab::directadd)) {
 	imcontact ic(sp.nick, sp.pname);
 	static icqcontact *singlec = 0, *c;
@@ -785,6 +796,9 @@ bool icqface::findresults(const imsearchparams &sp, bool fauto) {
 	finished = !db.open(r, b);
 	h.stoplookup();
 
+	if(h.getCapabs().count(hookcapab::nochat) && b > 0)
+	    b++;
+
 	if(!finished) {
 	    if(r == -3) {
 		quickfind(db.getmenu());
@@ -898,6 +912,38 @@ void commaform(string &text) {
     }
 }
 
+void icqface::infolivejournal(dialogbox &db, icqcontact *c) {
+    icqcontact::basicinfo bi = c->getbasicinfo();
+    icqcontact::moreinfo mi = c->getmoreinfo();
+
+    workarealine(sizeWArea.y1+5);
+    workarealine(sizeWArea.y1+7);
+
+    mainw.write(sizeWArea.x1+2, sizeWArea.y1+2, conf.getcolor(cp_main_highlight), _("Nickname"));
+    mainw.write(sizeWArea.x1+2, sizeWArea.y1+3, conf.getcolor(cp_main_highlight), _("Name"));
+    mainw.write(sizeWArea.x1+2, sizeWArea.y1+5, conf.getcolor(cp_main_highlight), _("URL"));
+
+    mainw.write(sizeWArea.x1+14, sizeWArea.y1+2, conf.getcolor(cp_main_text), c->getnick());
+    mainw.write(sizeWArea.x1+14, sizeWArea.y1+3, conf.getcolor(cp_main_text), bi.fname + " " + bi.lname);
+    mainw.write(sizeWArea.x1+14, sizeWArea.y1+5, conf.getcolor(cp_main_text), mi.homepage);
+
+    mainw.write(sizeWArea.x1+2, sizeWArea.y1+7, conf.getcolor(cp_main_highlight), _("This is your LiveJournal account. Use it to"));
+    mainw.write(sizeWArea.x1+2, sizeWArea.y1+8, conf.getcolor(cp_main_highlight), _("post new entries to your journal."));
+}
+
+void icqface::infofriends(dialogbox &db, icqcontact *c) {
+    string text, buf;
+    icqcontact::basicinfo bi = c->getbasicinfo();
+
+    text += (string) "* " + _("The following users have you listed as their friend:") + " ";
+    while(!(buf = getword(bi.zip)).empty()) {
+	text += buf;
+	if(!bi.zip.empty()) text += ", ";
+    }
+
+    db.getbrowser()->setbuf(text);
+}
+
 void icqface::infogeneral(dialogbox &db, icqcontact *c) {
     string langs, options;
     icqcontact::basicinfo bi = c->getbasicinfo();
@@ -1098,16 +1144,16 @@ void icqface::inforss(dialogbox &db, icqcontact *c) {
     string freq, last, next;
     char buf[512];
 
-    if(mi.birth_day) {
-	sprintf(buf, _("%lu minutes"), mi.birth_day);
+    if(mi.checkfreq) {
+	sprintf(buf, _("%lu minutes"), mi.checkfreq);
 	freq = buf;
-	if(mi.birth_month) next = strdateandtime(mi.birth_month+mi.birth_day*60);
+	if(mi.checklast) next = strdateandtime(mi.checklast+mi.checkfreq*60);
 	    else next = _("Now");
     } else {
 	freq = next = _("Never");
     }
 
-    if(mi.birth_month) last = strdateandtime(mi.birth_month);
+    if(mi.checklast) last = strdateandtime(mi.checklast);
 	else last = _("Never");
 
     mainw.write(sizeWArea.x1+14, sizeWArea.y1+10, conf.getcolor(cp_main_text), freq);
@@ -1116,6 +1162,17 @@ void icqface::inforss(dialogbox &db, icqcontact *c) {
     mainw.write(sizeWArea.x1+14, sizeWArea.y1+13, conf.getcolor(cp_main_text), bi.lname);
 }
 
+void icqface::infoljrss(dialogbox &db, icqcontact *c) {
+    icqcontact::basicinfo bi = c->getbasicinfo();
+    icqcontact::moreinfo mi = c->getmoreinfo();
+
+    mainw.write(sizeWArea.x1+2, sizeWArea.y1+2, conf.getcolor(cp_main_highlight), _("Birthdate"));
+    mainw.write(sizeWArea.x1+2, sizeWArea.y1+3, conf.getcolor(cp_main_highlight), _("Full name"));
+
+    mainw.write(sizeWArea.x1+14, sizeWArea.y1+2, conf.getcolor(cp_main_text), mi.strbirthdate());
+    mainw.write(sizeWArea.x1+14, sizeWArea.y1+3, conf.getcolor(cp_main_text), bi.email);
+}
+
 void icqface::userinfo(const imcontact &cinfo, const imcontact &realinfo) {
     bool finished = false, showinfo;
     textbrowser tb(conf.getcolor(cp_main_text));
@@ -1134,15 +1191,29 @@ void icqface::userinfo(const imcontact &cinfo, const imcontact &realinfo) {
     db.setwindow(new textwindow(sizeWArea.x1+1, sizeWArea.y1+2, sizeWArea.x2,
 	sizeWArea.y2, conf.getcolor(cp_main_text), TW_NOBORDER));
 
-    if(cinfo.pname != rss) {
+    if(cinfo.pname == rss) {
+	if(c->inlist() && realinfo != contactroot) {
+	    db.setbar(new horizontalbar(sizeWArea.x1+2, sizeWArea.y2-1,
+		conf.getcolor(cp_main_highlight), conf.getcolor(cp_main_selected),
+		_("Info"), _("About"), _("Check"), _("Edit"), islivejournal(c) ? _("LJ") : 0, 0));
+	} else {
+	    db.setbar(new horizontalbar(sizeWArea.x1+2, sizeWArea.y2-1,
+		conf.getcolor(cp_main_highlight), conf.getcolor(cp_main_selected),
+		_("Info"), _("About"), _("Retreive"), 0));
+	}
+
+    } else if(cinfo.pname == livejournal) {
+	db.setbar(new horizontalbar(sizeWArea.x1+2, sizeWArea.y2-1,
+	    conf.getcolor(cp_main_highlight), conf.getcolor(cp_main_selected),
+	    _("Info"), _("Friend of"), 0));
+
+
+    } else {
 	db.setbar(new horizontalbar(sizeWArea.x1+2, sizeWArea.y2-1,
 	    conf.getcolor(cp_main_highlight), conf.getcolor(cp_main_selected),
 	    _("Info"), _("Home"), _("Work"), _("More"), _("About"),
 	    cinfo.pname != infocard ? _("Retrieve") : _("Edit"), 0));
-    } else {
-	db.setbar(new horizontalbar(sizeWArea.x1+2, sizeWArea.y2-1,
-	    conf.getcolor(cp_main_highlight), conf.getcolor(cp_main_selected),
-	    _("Info"), _("About"), _("Check"), _("Edit"), 0));
+
     }
 
     showinfo = true;
@@ -1167,8 +1238,33 @@ void icqface::userinfo(const imcontact &cinfo, const imcontact &realinfo) {
 	    db.setbrowser(0);
 	    infoclear(db, c, cinfo);
 
-	    if(cinfo.pname != rss)
-	    switch(b) {
+	    if(cinfo.pname == rss) switch(b) {
+		case 0: inforss(db, c); break;
+		case 1: 
+		    db.setbrowser(&tb, false);
+		    infoabout(db, c);
+		    infoclear(db, c, cinfo);
+		    break;
+		case 2:
+		    gethook(cinfo.pname).ping(c);
+		    b = lastb;
+		    continue;
+		case 3:
+		    updatedetails(c, c->getdesc().pname);
+		    showinfo = true;
+		    b = lastb;
+		    continue;
+		case 4: infoljrss(db, c); break;
+
+	    } else if(cinfo.pname == livejournal) switch(b) {
+		case 0: infolivejournal(db, c); break;
+		case 1:
+		    db.setbrowser(&tb, false);
+		    infofriends(db, c);
+		    infoclear(db, c, cinfo);
+		    break;
+
+	    } else switch(b) {
 		case 0: infogeneral(db, c); break;
 		case 1: infohome(db, c); break;
 		case 2: infowork(db, c); break;
@@ -1197,24 +1293,9 @@ void icqface::userinfo(const imcontact &cinfo, const imcontact &realinfo) {
 		    b = lastb;
 		    continue;
 
-	    } else switch(b) {
-		case 0: inforss(db, c); break;
-		case 1: 
-		    db.setbrowser(&tb, false);
-		    infoabout(db, c);
-		    infoclear(db, c, cinfo);
-		    break;
-		case 2:
-		    gethook(cinfo.pname).ping(c);
-		    b = lastb;
-		    continue;
-		case 3:
-		    updatedetails(c, c->getdesc().pname);
-		    showinfo = true;
-		    b = lastb;
-		    continue;
 	    }
 
+
 	    refresh();
 	    showinfo = false;
 	    lastb = b;
@@ -1344,6 +1425,8 @@ bool icqface::changestatus(vector<protocolname> &pnames, imstatus &st) {
 	    m.setpos(0);
 	}
 
+	m.otherkeys = &statuskeys;
+
 	m.scale();
 
 	i = m.open();
@@ -1359,7 +1442,7 @@ bool icqface::changestatus(vector<protocolname> &pnames, imstatus &st) {
 
 #define INPUT_POS       LINES-2
 
-string icqface::inputstr(const string &q, const string &defl , char passwdchar ) {
+string icqface::inputstr(const string &q, const string &defl, char passwdchar) {
     screenarea sa(0, INPUT_POS, COLS, INPUT_POS);
 
     attrset(conf.getcolor(cp_status));
@@ -1957,7 +2040,7 @@ void icqface::showextractedurls() {
 	    m.additem(" " + *i);
 
 	if(n = m.open())
-	    conf.openurl(extractedurls[n-1]);
+	    conf.execaction("openurl", extractedurls[n-1]);
 
 	restoreworkarea();
     }
@@ -2038,12 +2121,13 @@ bool icqface::eventedit(imevent &ev) {
     showeventbottom(ev.getcontact());
 
     if(ev.gettype() == imevent::message) {
-	immessage *m = static_cast<immessage *>(&ev);
-
 	editor.setcoords(sizeWArea.x1+2, sizeWArea.y1+3, sizeWArea.x2, sizeWArea.y2);
-	editor.load(msg = m->gettext(), "");
-	editor.open();
 
+	immessage *m = static_cast<immessage *>(&ev);
+	editor.load(msg = m->gettext(), "");
+
+	editdone = false;
+	editor.open();
 	r = editdone;
 
 	auto_ptr<char> p(editor.save("\r\n"));
@@ -2052,6 +2136,31 @@ bool icqface::eventedit(imevent &ev) {
 	if((c = clist.get(ev.getcontact())) && (msg != p.get()))
 	    c->setpostponed(r ? "" : p.get());
 
+    } else if(ev.gettype() == imevent::xml) {
+	editor.setcoords(sizeWArea.x1+2, sizeWArea.y1+3, sizeWArea.x2, sizeWArea.y2);
+
+	while(1) {
+	    imxmlevent *m = static_cast<imxmlevent *>(&ev);
+	    editor.load(msg = m->gettext(), "");
+
+	    editdone = false;
+	    editor.open();
+	    r = editdone;
+
+	    auto_ptr<char> p(editor.save("\r\n"));
+	    m->setfield("text", p.get());
+
+	    if(r)
+	    if(ev.getcontact().pname == livejournal)
+	    if(!setljparams(m))
+		continue;
+
+	    if((c = clist.get(ev.getcontact())) && (msg != p.get()))
+		c->setpostponed(r ? "" : p.get());
+
+	    break;
+	}
+
     } else if(ev.gettype() == imevent::url) {
 	static textinputline urlinp;
 	imurl *m = static_cast<imurl *>(&ev);
@@ -2417,11 +2526,13 @@ vector<eventviewresult> abuttons, bool nobuttons) {
     vector<eventviewresult>::iterator ia;
 
     if(!nobuttons) {
-	if(ev->gettype() == imevent::message || ev->gettype() == imevent::notification) {
+	if(ev->gettype() == imevent::message
+	|| ev->gettype() == imevent::notification
+	|| ev->gettype() == imevent::xml) {
 	    actions.push_back(forward);
 
 	    if(ev->getdirection() == imevent::incoming)
-	    if(ev->getcontact().pname != rss)
+	    if(ev->getcontact().pname != rss || islivejournal(ev->getcontact()))
 		actions.push_back(reply);
 
 	} else if(ev->gettype() == imevent::url) {
@@ -2975,6 +3086,14 @@ int icqface::findreskeys(dialogbox &db, int k) {
     return -1;
 }
 
+int icqface::statuskeys(verticalmenu &m, int k) {
+    char *status_order = "o_adncfi";    // Shortcuts for status
+    char *p = strchr(status_order, k);
+    if (p)
+	return (1 + p - status_order);
+    return -1;
+}
+
 void icqface::editidle(texteditor &e) {
     cicq.idle();
 }
