@@ -25,7 +25,7 @@ enum interfaceAction {
     ACT_PING, ACT_EDITUSER, ACT_VISIBLELIST, ACT_INVISLIST, ACT_QUICKFIND,
     ACT_FILE, ACT_GROUPMOVE, ACT_ORG_GROUPS, ACT_HIDEOFFLINE, ACT_FETCHAWAY,
     ACT_EMAIL, ACT_AUTH, ACT_CONTACT, ACT_VERSION, ACT_JOIN, ACT_LEAVE,
-    ACT_CONFER, ACT_TRANSFERS, ACT_JOINDIALOG, ACT_EXTERN, ACT_RSS
+    ACT_CONFER, ACT_TRANSFERS, ACT_JOINDIALOG, ACT_EXTERN, ACT_RSS, ACT_LJ
 };
 
 extern class centericq cicq;
@@ -113,6 +113,7 @@ class icqface {
 	static int userinfokeys(dialogbox &db, int k);
 	static int findreskeys(dialogbox &db, int k);
 	static int eventviewkeys(dialogbox &db, int k);
+	static int statuskeys(verticalmenu &m, int k);
 
 	static void editidle(texteditor &e);
 	static void textbrowseridle(textbrowser &b);
@@ -132,6 +133,9 @@ class icqface {
 	void infoabout(dialogbox &db, icqcontact *c);
 
 	void inforss(dialogbox &db, icqcontact *c);
+	void infolivejournal(dialogbox &db, icqcontact *c);
+	void infofriends(dialogbox &db, icqcontact *c);
+	void infoljrss(dialogbox &db, icqcontact *c);
 
 	void gendetails(treeview *tree, icqcontact *c = 0);
 
@@ -153,6 +157,9 @@ class icqface {
 	bool sprofmanager(string &name, string &act);
 	void showeventbottom(const imcontact &ic);
 
+	void invokelist(string &s, vector<string> &v, const string &def, textwindow *w);
+	bool setljparams(imxmlevent *ev);
+
     public:
 	int extk;
 	vector<imcontact> muins;
